@@ -9,5 +9,5 @@ SEATTLE = CDPInstanceConfig(
     database_object_kwargs={"project_id": "cdp-seattle"},
     file_store_module_path="cdptools.file_stores.gcs_file_store",
     file_store_object_name="GCSFileStore",
-    file_store_object_kwargs={"bucket_name": "cdp-seattle.appspot.com"}
+    file_store_object_kwargs={"bucket_name": "cdp-seattle.appspot.com"},
 )
